/* wptW32API.h - Common API interface
 *	Copyright (C) 2001-2005 Timo Schulz
 *
 * This file is part of WinPT.
 *
 * WinPT is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 
 * as published by the Free Software Foundation; either version 2 
 * of the License, or (at your option) any later version.
 *  
 * WinPT is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with WinPT; if not, write to the Free Software Foundation, 
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA 
 */

#ifndef WPT_W32_API_H
#define WPT_W32_API_H

#include "wptCrypto.h"
#include "wptUtil.h"

struct curr_wnd_ctx {
    HWND main;
    HWND focus;
};

struct LOCK {
    char *file;
    int size;
    HANDLE fh;
};


/*-- wptMAPI.cpp --*/
int mapi_init (void);
int mapi_send_pubkey (const char * keyid, char * keyfile);
int mapi_send_ascfile (char * ascfile);
void mapi_deinit (void);

/*-- wptW32API.cpp --*/
char* make_filename (const char *path, const char *file, const char *ext);
int init_file_lock (LOCK *ctx, const char *file);
void release_file_lock (LOCK *ctx);
int file_exist_check (const char *fname);
int dir_exist_check (const char *dir);
DWORD get_file_size (const char *fname);
int get_file_version (const char *fname, WORD *major, WORD *minor, 
		      WORD *patch1, WORD *patch2);

int get_window_contents( HWND old_hwnd, curr_wnd_ctx *ctx, int *r_hotkey );
int set_window_contents( HWND old_hwnd, curr_wnd_ctx *ctx );

void center_window (HWND hwndChild, HWND hwndParent);
void center_window2 (HWND hwndChild, HWND parent, HWND style);
void force_foreground_window (HWND dlg, int msecs);

void set_menu_text (HMENU menu, UINT m_uid, const char *text);
void set_menu_text_bypos (HMENU menu, UINT pos, const char *text);
void set_menu_state (HMENU menu, UINT m_uid, UINT state);
UINT get_menu_state (HMENU menu, UINT m_uid);

char* get_clip_text (HWND hwnd);
int set_clip_text (HWND hwnd, const char *text, int nbytes);
int set_clip_text2 (HWND hwnd, const char *text, int nbytes, int as_footer);
int dialog_box_param( HINSTANCE hinst, LPCTSTR name, HWND parent, DLGPROC fnc,
		     LPARAM param, LPCTSTR title, int title_id );
int msg_box( HWND hwnd, const char *text, const char *title, int mode );
int check_date( SYSTEMTIME *st );
const char* get_filesave_dlg (HWND hwnd, const char *title,
			      const char *filter, const char *name);
const char* get_fileopen_dlg (HWND hwnd, const char *title,
			      const char *filter, const char *name);
const char * get_folder_dlg( HWND hwnd, const char * title, const char * name );
char * m_strdup (const char *str);
const char * strtimestamp (long timestamp);
const char* get_locale_date (long tm_t, char *buf, DWORD buflen);


#define listbox_add_string(lb, string) \
    SendMessage( (lb), LB_ADDSTRING, 0, (LPARAM)(LPCSTR)(string) )

#define listbox_get_cursel(lb) \
    SendMessage( (lb), LB_GETCURSEL, 0, 0 )

#define combox_add_string(cb, string) \
    SendMessage( (cb), CB_ADDSTRING, 0, (LPARAM)(LPCSTR)(string) )

#define item_get_text_length(dlg, itm) \
	SendDlgItemMessage ((dlg), (itm), WM_GETTEXTLENGTH, 0, 0)

#ifdef _MSC_VER
#include <htmlhelp.h>

/* Support for the new html context sentensive help. For
   now it can be only used with native W32 compilers. */
#define html_help_init(cookie) \
    HtmlHelp (NULL, NULL, HH_INITIALIZE, (DWORD)(cookie))

#define html_help_deinit() \
    HtmlHelp (NULL, NULL, HH_UNINITIALIZE, 0)

#define html_help_dispatch(param, file, helparr) do { \
    HELPINFO *inf; \
    inf = (HELPINFO *)param; \
    if (inf->iContextType == HELPINFO_WINDOW) \
	HtmlHelp ((HWND)inf->hItemHandle, file, \
		   HH_TP_HELP_CONTEXTMENU, (DWORD)helparr); \
    } while (0)
#else
#define html_help_init(cookie) do {} while (0)
#define html_help_deinit() do {} while (0)
#define html_help_dispatch(param, file, helparr) do {} while (0)
#endif

#endif /* WPT_W32_API_H */
